RegRip.py standard classes
==========================

Before executing a plugin, the following objects are inserted into the global namespace. 
Please refer to :doc:`createplugin` to learn how to develop a plugin yourself.

When using these objects from inside your plugin, do not specify the `regrip.` module, as 
these objects are directly injected, bypassing any import.

.. automodule:: regrippy
    :members: